Example 1: simple pseudo-Cl computation
=======================================

This sample script shows the simplest way to compute the cross-power spectrum between two fields

.. literalinclude:: ../../test/sample_simple.py
   :language: python
